#Topsis Calculator
It takes 4 inputs namely input file, weight vector, impact vector, output file

##installation
```pip install topsis-agrim-102003549```

##License
u"\u00A9" 2023 Agrim Sood

This repository iss licensed under MIT License.
See License for details.